diff --git a/c_gui/images/casa.glade b/c_gui/images/casa.glade
index a7d960ea..b087eead 100644
--- a/c_gui/images/casa.glade
+++ b/c_gui/images/casa.glade
@@ -7838,6 +7838,31 @@ prompted for the Master Password at startup.
0
True
True
+
+
+
+
+
+ True
+
+ True
+ True
+ GTK_JUSTIFY_LEFT
+ False
+ False
+ 0.5
+ 0.5
+ 0
+ 0
+ PANGO_ELLIPSIZE_NONE
+ -1
+ False
+ 0
+
+
+ 0
+ False
+ False
diff --git a/c_gui/CasaMain.cs b/c_gui/CasaMain.cs
index 208c5bf8..2db31176 100644
--- a/c_gui/CasaMain.cs
+++ b/c_gui/CasaMain.cs
@@ -179,14 +179,16 @@ namespace Novell.CASA.GUI
}
else
{
- if (Common.IS_LINUX)
+ // NOTE: Until we can figure out how to run YAST as root from here.
+ //if (Common.IS_LINUX)
+ if (false)
{
message = "CASA services are not available.\r\n\r\nConfigure CASA using YAST?";
buttonType = Gtk.ButtonsType.YesNo;
}
else
{
- message = "CASA services are not available";
+ message = "CASA services are not available.\r\n\r\nPlease contact your adminstrator to configure CASA.";
}
}
@@ -417,25 +419,35 @@ namespace Novell.CASA.GUI
if (entryDesktopPassword1.Text.Equals(entryDesktopPassword2.Text))
{
- // set the desktop password in micasa
- try
- {
- Novell.CASA.miCASA.SetCredential(0,
- "Desktop",
- null,
- Novell.CASA.miCASA.USERNAME_TYPE_CN_F,
- GetLocalUsername(),
- entryDesktopPassword1.Text);
- }
- catch (Exception e)
- {
- Logger.DbgLog(e.ToString());
- }
- if (dialogDesktopPassword != null)
- dialogDesktopPassword.Destroy();
+ // validate entered desktop password
+ if (miCASA.ValidateDesktopPwd(entryDesktopPassword1.Text))
+ {
+ // set the desktop password in micasa
+ try
+ {
+ Novell.CASA.miCASA.SetCredential(0,
+ "Desktop",
+ null,
+ Novell.CASA.miCASA.USERNAME_TYPE_CN_F,
+ GetLocalUsername(),
+ entryDesktopPassword1.Text);
+ }
+
+ catch (Exception e)
+ {
+ Logger.DbgLog(e.ToString());
+ }
- MasterPasswordAuthentication();
+ if (dialogDesktopPassword != null)
+ dialogDesktopPassword.Destroy();
+
+ MasterPasswordAuthentication();
+ }
+ else
+ {
+ labelDesktopPasswordMessage.Text = "Your desktop password does not match";
+ }
}
else
{